==> fluxbox-0.9.13.tar.bz2: fluxbox-0.9.13/nls/tr_TR/Translation.m <==
$ codeset=ISO-8859-1

$set 1 #Align

1 Alt orta
2 Sol alt
3 Sa st
4 Yatay
6 Orta sol
7 Sol orta
8 Sol st
11 Sa orta
12 Orta sa
13 Sa st
14 st orta
15 Sol st
16 Sa st
17 Dikey

$set 2 #BaseDisplay


$set 3 #Common

2 Otomatik Gizle

$set 4 #Configmenu

2 Otomatik Gster
4 Hizalamak iin tkla
7 Masast deiiminde pencereyi hizala
8 Hizalama
9 Yeni Pencereleri Hizala
10 Ekran Kapla
11 Resim oluturulmas
12 Donuk Pencere Tanmas
13 Aynlar Hizala
14 Yava Hizala
15 Masast Sapmas

$set 5 #Ewmh


$set 6 #FbTkError


$set 7 #Fluxbox


$set 8 #Gnome


$set 9 #Keys


$set 10 #Menu

3 k
4 konlar
7 Yerleim
9 Yeniden Balat
10 xterm

$set 11 #Remember


$set 12 #Screen

2 Y: %4d x E: %4d
5 X: %4d x Y: %4d
6 0: 0000 x 0: 0000

$set 13 #Slit

4 Slit yn
7 Slit yerleimi
8 Slit

$set 14 #Toolbar

1 Masast ismini deitir
10 Ara ubuu Yerleimi
11 Ara ubuu

$set 15 #Window

1 simsiz

$set 16 #Windowmenu

1 Kapat
2 Klt
4 Klt
5 Ekran Kapla
6 Gster
7 Gnder ...
8 ekillendir
9 Yaptr

$set 17 #Workspace

1 Masast %d
2 Masastleri
3 Yeni Masast
4 Son Masastn Kaldr

$set 18 #bsetroot

1 %s : hata : -solid, -mod yada -gradient'den en az birisini belirlemek zorundasnz\n
3 %s 2.0 : Telif hakk (c) 1997-2000 Brad Hughes\n\n\
-display <metin>         balanty gster\n\
-mod <x> <y>             yerletirme\n\
-foreground, -fg <renk>  nplan rengi\n\
-background, -bg <renk>  arkaplan rengi\n\n\
-gradient <doku>         gei dokusu\n\
-from <renk>             gei balama rengi\n\
-to <renk>               gei biti rengi\n\n\
-solid <renk>            tek renk\n\n\
-help                    bu yardm iletisini gsterir\n

$set 19 #main

1 hata : '-display' bir argman gerektirir\n
11 hata : '-rc' bir argman gerektirir\n
12 Fluxbox %s: (c) %s Henrik Kinnunen\n\n\
-display <metin>\t\tekran balants kullan.\n\
-rc <metin>\t\t\talternatif bir ayar kaynak dosyas kullan.\n\
-version\t\t\tsrm gster.\n\
-info\t\t\t\tdisplay some useful information.\n\
-log <filename>\t\t\tlog output to file.\n\
-help\t\t\t\tyardm ekran.\n\n

==> fluxbox-1.0rc2.tar.bz2: fluxbox-1.0rc2/nls/tr_TR/Translation.m <==
$ codeset=ISO-8859-1

$set 1 #Align

1 Alt orta
2 Sol alt
3 Sa st
4 Yatay
6 Orta sol
7 Sol orta
8 Sol st
11 Sa orta
12 Orta sa
13 Sa st
14 st orta
15 Sol st
16 Sa st
17 Dikey

$set 2 #BaseDisplay


$set 3 #Common

2 Otomatik Gizle

$set 4 #Configmenu

2 Otomatik Gster
4 Hizalamak iin tkla
7 Masast deiiminde pencereyi hizala
8 Hizalama
9 Yeni Pencereleri Hizala
10 Ekran Kapla
11 Resim oluturulmas
12 Donuk Pencere Tanmas
13 Aynlar Hizala
14 Yava Hizala
15 Masast Sapmas

$set 5 #Ewmh


$set 6 #FbTkError


$set 7 #Fluxbox


$set 8 #Gnome


$set 9 #Keys


$set 10 #Menu

3 k
4 konlar
7 Yerleim
9 Yeniden Balat

$set 11 #Remember


$set 12 #Screen

2 Y: %4d x E: %4d

$set 13 #Slit

4 Slit yn
7 Slit yerleimi
8 Slit

$set 14 #Toolbar

1 Masast ismini deitir
10 Ara ubuu Yerleimi
11 Ara ubuu

$set 15 #Window

1 simsiz

$set 16 #Windowmenu

1 Kapat
2 Klt
4 Klt
5 Ekran Kapla
6 Gster
7 Gnder ...
8 ekillendir
9 Yaptr

$set 17 #Workspace

1 Masast %d
2 Masastleri
3 Yeni Masast
4 Son Masastn Kaldr

$set 18 #fbsetroot

1 hata : -solid, -mod yada -gradient'den en az birisini belirlemek zorundasnz\n
3 -display <metin>         balanty gster\n\
-mod <x> <y>             yerletirme\n\
-foreground, -fg <renk>  nplan rengi\n\
-background, -bg <renk>  arkaplan rengi\n\n\
-gradient <doku>         gei dokusu\n\
-from <renk>             gei balama rengi\n\
-to <renk>               gei biti rengi\n\n\
-solid <renk>            tek renk\n\n\
-help                    bu yardm iletisini gsterir\n

$set 19 #main

1 hata : '-display' bir argman gerektirir
11 hata : '-rc' bir argman gerektirir
13 Fluxbox %s: (c) %s Henrik Kinnunen\n\n\
-display <metin>\t\tekran balants kullan.\n\
-rc <metin>\t\t\talternatif bir ayar kaynak dosyas kullan.\n\
-version\t\t\tsrm gster.\n\
-info\t\t\t\tdisplay some useful information.\n\
-log <filename>\t\t\tlog output to file.\n\
-help\t\t\t\tyardm ekran.\n\n
